pub struct Bookmark {
pub name: String,
pub query: String,
pub description: Option<String>,
pub created_at: String,
pub last_modified: String,
}Expand description
Represents a single saved SQL query bookmark.
This struct contains the details of a bookmark, including its name, the SQL query itself, an optional description, and timestamps for creation and last modification.
Fields
name: Stringquery: Stringdescription: Option<String>created_at: Stringlast_modified: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Bookmark
impl<'de> Deserialize<'de> for Bookmark
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more