pub struct ProgressiveLoader { /* private fields */ }Expand description
A helper for loading and displaying large result sets in batches to avoid high memory usage.
Note: This feature is experimental and not currently integrated into the REPL or CLI.
Implementations