pub struct QueryCache { /* private fields */ }Expand description
A cache for storing and retrieving query results to improve performance for repeated queries.
Note: This feature is experimental and not currently integrated into the REPL or CLI.
Implementations