pub fn execute_sql(
conn: &Connection,
sql: &str,
options: &QueryOptions,
) -> Result<()>Expand description
Execute a SQL command and display the results with enhanced formatting and timing
pub fn execute_sql(
conn: &Connection,
sql: &str,
options: &QueryOptions,
) -> Result<()>Execute a SQL command and display the results with enhanced formatting and timing