pub enum ShellAction {
Exit,
SwitchToRepl,
}Expand description
Defines the possible actions that can be returned from the shell session. This is used to signal whether the user wants to exit the application entirely or switch back to the SQL REPL.
Variants