pub fn shell_mode(db_path: &str) -> Result<ShellAction>Expand description
Start shell mode with database context Start shell mode with database context
pub fn shell_mode(db_path: &str) -> Result<ShellAction>Start shell mode with database context Start shell mode with database context